@@ -120,7 +120,7 @@ KEnterScheduleDlg::KEnterScheduleDlg(QWidget *parent, const MyMoneySchedule& sch
   d->m_schedule = schedule;
   d->m_extendedReturnCode = eDialogs::ScheduleResultCode::Enter;
   d->ui->buttonOk->setIcon(Icons::get(Icon::KeyEnter));
-  d->ui->buttonSkip->setIcon(Icons::get(Icon::MediaSeekForward));
+  d->ui->buttonSkip->setIcon(Icons::get(Icon::SeekForward));
   KGuiItem::assign(d->ui->buttonCancel, KStandardGuiItem::cancel());
   KGuiItem::assign(d->ui->buttonHelp, KStandardGuiItem::help());
   d->ui->buttonIgnore->setHidden(true);
@@ -394,7 +394,7 @@ bool KEnterScheduleDlg::focusNextPrevChild(bool next)
 
     if (((w->focusPolicy() & Qt::TabFocus) == Qt::TabFocus) && w->isVisible() && w->isEnabled()) {
       // qDebug("Selecting '%s' as focus", w->className());
-      w->setFocus();
+      w->setFocus(next ? Qt::TabFocusReason: Qt::BacktabFocusReason);
       rc = true;
     }
   }
