@@ -24,6 +24,7 @@
 // QT Includes
 
 #include <QDate>
+#include <QFlags>
 #include <QDebug>
 
 // ----------------------------------------------------------------------------
@@ -48,17 +49,20 @@ public:
   MyMoneyTransactionFilterPrivate()
     : m_reportAllSplits(false)
     , m_considerCategory(false)
+    , m_considerCategorySplits(false)
     , m_matchOnly(false)
+    , m_treatTransfersAsIncomeExpense(false)
     , m_matchingSplitsCount(0)
     , m_invertText(false)
   {
-    m_filterSet.allFilter = 0;
   }
 
   MyMoneyTransactionFilter::FilterSet m_filterSet;
   bool                m_reportAllSplits;
   bool                m_considerCategory;
+  bool                m_considerCategorySplits;
   bool                m_matchOnly;
+  bool                m_treatTransfersAsIncomeExpense;
 
   uint                m_matchingSplitsCount;
 
@@ -104,7 +108,7 @@ MyMoneyTransactionFilter::~MyMoneyTransactionFilter()
 void MyMoneyTransactionFilter::clear()
 {
   Q_D(MyMoneyTransactionFilter);
-  d->m_filterSet.allFilter = 0;
+  d->m_filterSet = {};
   d->m_invertText = false;
   d->m_accounts.clear();
   d->m_categories.clear();
@@ -120,14 +124,14 @@ void MyMoneyTransactionFilter::clear()
 void MyMoneyTransactionFilter::clearAccountFilter()
 {
   Q_D(MyMoneyTransactionFilter);
-  d->m_filterSet.singleFilter.accountFilter = 0;
+  d->m_filterSet.setFlag(accountFilterActive);
   d->m_accounts.clear();
 }
 
 void MyMoneyTransactionFilter::setTextFilter(const QRegExp& text, bool invert)
 {
   Q_D(MyMoneyTransactionFilter);
-  d->m_filterSet.singleFilter.textFilter = 1;
+  d->m_filterSet.setFlag(textFilterActive);
   d->m_invertText = invert;
   d->m_text = text;
 }
@@ -136,7 +140,7 @@ void MyMoneyTransactionFilter::addAccount(const QStringList& ids)
 {
   Q_D(MyMoneyTransactionFilter);
 
-  d->m_filterSet.singleFilter.accountFilter = 1;
+  d->m_filterSet.setFlag(accountFilterActive);
   for (const auto& id : ids)
     addAccount(id);
 }
@@ -148,7 +152,7 @@ void MyMoneyTransactionFilter::addAccount(const QString& id)
       d->m_accounts.contains(id))
     return;
 
-  d->m_filterSet.singleFilter.accountFilter = 1;
+  d->m_filterSet.setFlag(accountFilterActive);
   if (!id.isEmpty())
     d->m_accounts.insert(id, QString());
 }
@@ -157,7 +161,7 @@ void MyMoneyTransactionFilter::addCategory(const QStringList& ids)
 {
   Q_D(MyMoneyTransactionFilter);
 
-  d->m_filterSet.singleFilter.categoryFilter = 1;
+  d->m_filterSet.setFlag(categoryFilterActive);
   for (const auto& id : ids)
     addCategory(id);
 }
@@ -169,7 +173,7 @@ void MyMoneyTransactionFilter::addCategory(const QString& id)
       d->m_categories.contains(id))
     return;
 
-  d->m_filterSet.singleFilter.categoryFilter = 1;
+  d->m_filterSet.setFlag(categoryFilterActive);
   if (!id.isEmpty())
     d->m_categories.insert(id, QString());
 }
@@ -177,7 +181,7 @@ void MyMoneyTransactionFilter::addCategory(const QString& id)
 void MyMoneyTransactionFilter::setDateFilter(const QDate& from, const QDate& to)
 {
   Q_D(MyMoneyTransactionFilter);
-  d->m_filterSet.singleFilter.dateFilter = from.isValid() | to.isValid();
+  d->m_filterSet.setFlag(dateFilterActive, from.isValid() | to.isValid());
   d->m_fromDate = from;
   d->m_toDate = to;
 }
@@ -185,7 +189,7 @@ void MyMoneyTransactionFilter::setDateFilter(const QDate& from, const QDate& to)
 void MyMoneyTransactionFilter::setAmountFilter(const MyMoneyMoney& from, const MyMoneyMoney& to)
 {
   Q_D(MyMoneyTransactionFilter);
-  d->m_filterSet.singleFilter.amountFilter = 1;
+  d->m_filterSet.setFlag(amountFilterActive);
   d->m_fromAmount = from.abs();
   d->m_toAmount = to.abs();
 
@@ -201,7 +205,7 @@ void MyMoneyTransactionFilter::addPayee(const QString& id)
       d->m_payees.contains(id))
     return;
 
-  d->m_filterSet.singleFilter.payeeFilter = 1;
+  d->m_filterSet.setFlag(payeeFilterActive);
   if (!id.isEmpty())
     d->m_payees.insert(id, QString());
 }
@@ -213,7 +217,7 @@ void MyMoneyTransactionFilter::addTag(const QString& id)
       d->m_tags.contains(id))
     return;
 
-  d->m_filterSet.singleFilter.tagFilter = 1;
+  d->m_filterSet.setFlag(tagFilterActive);
   if (!id.isEmpty())
     d->m_tags.insert(id, QString());
 }
@@ -225,7 +229,7 @@ void MyMoneyTransactionFilter::addType(const int type)
       d->m_types.contains(type))
     return;
 
-  d->m_filterSet.singleFilter.typeFilter = 1;
+  d->m_filterSet.setFlag(typeFilterActive);
   d->m_types.insert(type, QString());
 }
 
@@ -236,7 +240,7 @@ void MyMoneyTransactionFilter::addState(const int state)
       d->m_states.contains(state))
     return;
 
-  d->m_filterSet.singleFilter.stateFilter = 1;
+  d->m_filterSet.setFlag(stateFilterActive);
   d->m_states.insert(state, QString());
 }
 
@@ -247,14 +251,14 @@ void MyMoneyTransactionFilter::addValidity(const int type)
       d->m_validity.contains(type))
     return;
 
-  d->m_filterSet.singleFilter.validityFilter = 1;
+  d->m_filterSet.setFlag(validityFilterActive);
   d->m_validity.insert(type, QString());
 }
 
 void MyMoneyTransactionFilter::setNumberFilter(const QString& from, const QString& to)
 {
   Q_D(MyMoneyTransactionFilter);
-  d->m_filterSet.singleFilter.nrFilter = 1;
+  d->m_filterSet.setFlag(nrFilterActive);
   d->m_fromNr = from;
   d->m_toNr = to;
 }
@@ -265,12 +269,30 @@ void MyMoneyTransactionFilter::setReportAllSplits(const bool report)
   d->m_reportAllSplits = report;
 }
 
+void MyMoneyTransactionFilter::setConsiderCategorySplits(const bool check)
+{
+  Q_D(MyMoneyTransactionFilter);
+  d->m_considerCategorySplits = check;
+}
+
 void MyMoneyTransactionFilter::setConsiderCategory(const bool check)
 {
   Q_D(MyMoneyTransactionFilter);
   d->m_considerCategory = check;
 }
 
+void MyMoneyTransactionFilter::setTreatTransfersAsIncomeExpense(const bool check)
+{
+  Q_D(MyMoneyTransactionFilter);
+  d->m_treatTransfersAsIncomeExpense = check;
+}
+
+bool MyMoneyTransactionFilter::treatTransfersAsIncomeExpense() const
+{
+  Q_D(const MyMoneyTransactionFilter);
+  return d->m_treatTransfersAsIncomeExpense;
+}
+
 uint MyMoneyTransactionFilter::matchingSplitsCount(const MyMoneyTransaction& transaction)
 {
   Q_D(MyMoneyTransactionFilter);
@@ -290,7 +312,7 @@ QVector<MyMoneySplit> MyMoneyTransactionFilter::matchingSplits(const MyMoneyTran
   // qDebug("T: %s", transaction.id().data());
   // if no filter is set, we can safely return a match
   // if we should report all splits, then we collect them
-  if (!d->m_filterSet.allFilter && d->m_reportAllSplits) {
+  if (!d->m_filterSet && d->m_reportAllSplits) {
     d->m_matchingSplitsCount = transaction.splitCount();
     if (!d->m_matchOnly)
       matchingSplits = QVector<MyMoneySplit>::fromList(transaction.splits());
@@ -298,12 +320,12 @@ QVector<MyMoneySplit> MyMoneyTransactionFilter::matchingSplits(const MyMoneyTran
   }
 
   d->m_matchingSplitsCount = 0;
-  const auto filter = d->m_filterSet.singleFilter;
+  const auto filter = d->m_filterSet;
 
   // perform checks on the MyMoneyTransaction object first
 
   // check the date range
-  if (filter.dateFilter) {
+  if (filter & dateFilterActive) {
     if ((d->m_fromDate != QDate() &&
          transaction.postDate() < d->m_fromDate) ||
         (d->m_toDate != QDate() &&
@@ -312,12 +334,12 @@ QVector<MyMoneySplit> MyMoneyTransactionFilter::matchingSplits(const MyMoneyTran
     }
   }
 
-  auto categoryMatched = !filter.categoryFilter;
-  auto accountMatched = !filter.accountFilter;
+  auto categoryMatched = !(filter & categoryFilterActive);
+  auto accountMatched = !(filter & accountFilterActive);
   auto isTransfer = true;
 
   // check the transaction's validity
-  if (filter.validityFilter) {
+  if (filter & validityFilterActive) {
     if (!d->m_validity.isEmpty() &&
         !d->m_validity.contains((int)validTransaction(transaction)))
       return matchingSplits;
@@ -329,18 +351,18 @@ QVector<MyMoneySplit> MyMoneyTransactionFilter::matchingSplits(const MyMoneyTran
   auto isMatchingSplitsEmpty = true;
 
   auto extendedFilter = d->m_filterSet;
-  extendedFilter.singleFilter.dateFilter = 0;
-  extendedFilter.singleFilter.accountFilter = 0;
-  extendedFilter.singleFilter.categoryFilter = 0;
+  extendedFilter.setFlag(dateFilterActive, false);
+  extendedFilter.setFlag(accountFilterActive, false);
+  extendedFilter.setFlag(categoryFilterActive, false);
 
-  if (filter.accountFilter ||
-      filter.categoryFilter ||
-      extendedFilter.allFilter) {
+  if (filter.testFlag(accountFilterActive) ||
+      filter.testFlag(categoryFilterActive) ||
+      extendedFilter != 0) {
     const auto& splits = transaction.splits();
     for (const auto& s : splits) {
 
-      if (filter.accountFilter ||
-          filter.categoryFilter) {
+      if (filter.testFlag(accountFilterActive) ||
+          filter.testFlag(categoryFilterActive)) {
         auto removeSplit = true;
         if (d->m_considerCategory) {
           switch (file->account(s.accountId()).accountGroup()) {
@@ -348,7 +370,7 @@ QVector<MyMoneySplit> MyMoneyTransactionFilter::matchingSplits(const MyMoneyTran
             case eMyMoney::Account::Type::Expense:
               isTransfer = false;
               // check if the split references one of the categories in the list
-              if (filter.categoryFilter) {
+              if (filter.testFlag(categoryFilterActive)) {
                 if (d->m_categories.isEmpty()) {
                   // we're looking for transactions with 'no' categories
                   d->m_matchingSplitsCount = 0;
@@ -363,7 +385,7 @@ QVector<MyMoneySplit> MyMoneyTransactionFilter::matchingSplits(const MyMoneyTran
 
             default:
               // check if the split references one of the accounts in the list
-              if (!filter.accountFilter) {
+              if (!filter.testFlag(accountFilterActive)) {
                 removeSplit = false;
               } else if (!d->m_accounts.isEmpty() &&
                          d->m_accounts.contains(s.accountId())) {
@@ -375,7 +397,7 @@ QVector<MyMoneySplit> MyMoneyTransactionFilter::matchingSplits(const MyMoneyTran
           }
 
         } else {
-          if (!filter.accountFilter) {
+          if (!filter.testFlag(accountFilterActive)) {
             removeSplit = false;
           } else if (!d->m_accounts.isEmpty() &&
                      d->m_accounts.contains(s.accountId())) {
@@ -389,7 +411,7 @@ QVector<MyMoneySplit> MyMoneyTransactionFilter::matchingSplits(const MyMoneyTran
       }
 
       // check if less frequent filters are active
-      if (extendedFilter.allFilter) {
+      if (extendedFilter != 0) {
         const auto acc = file->account(s.accountId());
         if (!(matchAmount(s) && matchText(s, acc)))
           continue;
@@ -404,9 +426,10 @@ QVector<MyMoneySplit> MyMoneyTransactionFilter::matchingSplits(const MyMoneyTran
             break;
         }
 
-        if (!isCategory) {
+        bool includeSplit = d->m_considerCategorySplits || (!d->m_considerCategorySplits && !isCategory);
+        if (includeSplit) {
           // check the payee list
-          if (filter.payeeFilter) {
+          if (filter.testFlag(payeeFilterActive)) {
             if (!d->m_payees.isEmpty()) {
               if (s.payeeId().isEmpty() || !d->m_payees.contains(s.payeeId()))
                 continue;
@@ -415,7 +438,7 @@ QVector<MyMoneySplit> MyMoneyTransactionFilter::matchingSplits(const MyMoneyTran
           }
 
           // check the tag list
-          if (filter.tagFilter) {
+          if (filter.testFlag(tagFilterActive)) {
             const auto tags = s.tagIdList();
             if (!d->m_tags.isEmpty()) {
               if (tags.isEmpty()) {
@@ -437,27 +460,23 @@ QVector<MyMoneySplit> MyMoneyTransactionFilter::matchingSplits(const MyMoneyTran
           }
 
           // check the type list
-          if (filter.typeFilter &&
+          if (filter.testFlag(typeFilterActive) &&
               !d->m_types.isEmpty() &&
               !d->m_types.contains(splitType(transaction, s, acc)))
             continue;
 
           // check the state list
-          if (filter.stateFilter &&
+          if (filter.testFlag(stateFilterActive) &&
               !d->m_states.isEmpty() &&
               !d->m_states.contains(splitState(s)))
             continue;
 
-          if (filter.nrFilter &&
+          if (filter.testFlag(nrFilterActive) &&
               ((!d->m_fromNr.isEmpty() && s.number() < d->m_fromNr) ||
                (!d->m_toNr.isEmpty() && s.number() > d->m_toNr)))
             continue;
 
-        } else if (filter.payeeFilter
-                   || filter.tagFilter
-                   || filter.typeFilter
-                   || filter.stateFilter
-                   || filter.nrFilter) {
+        } else if (filter & (payeeFilterActive | tagFilterActive | typeFilterActive | stateFilterActive | nrFilterActive)) {
           continue;
         }
       }
@@ -483,7 +502,7 @@ QVector<MyMoneySplit> MyMoneyTransactionFilter::matchingSplits(const MyMoneyTran
   // if there's no category filter and the category did not
   // match, then we still want to see this transaction if it's
   // a transfer
-  if (!categoryMatched && !filter.categoryFilter)
+  if (!categoryMatched && !filter.testFlag(categoryFilterActive))
     categoryMatched = isTransfer;
 
   if (isMatchingSplitsEmpty || !(accountMatched && categoryMatched)) {
@@ -521,7 +540,7 @@ bool MyMoneyTransactionFilter::matchText(const MyMoneySplit& s, const MyMoneyAcc
   Q_D(const MyMoneyTransactionFilter);
   // check if the text is contained in one of the fields
   // memo, value, number, payee, tag, account
-  if (d->m_filterSet.singleFilter.textFilter) {
+  if (d->m_filterSet & textFilterActive) {
     const auto file = MyMoneyFile::instance();
     const auto sec = file->security(acc.currencyId());
     if (s.memo().contains(d->m_text) ||
@@ -550,7 +569,7 @@ bool MyMoneyTransactionFilter::matchText(const MyMoneySplit& s, const MyMoneyAcc
 bool MyMoneyTransactionFilter::matchAmount(const MyMoneySplit& s) const
 {
   Q_D(const MyMoneyTransactionFilter);
-  if (d->m_filterSet.singleFilter.amountFilter) {
+  if (d->m_filterSet & amountFilterActive) {
     const auto value  = s.value().abs();
     const auto shares = s.shares().abs();
     if ((value  < d->m_fromAmount || value  > d->m_toAmount) &&
@@ -593,16 +612,15 @@ int MyMoneyTransactionFilter::splitState(const MyMoneySplit& split) const
 
 int MyMoneyTransactionFilter::splitType(const MyMoneyTransaction& t, const MyMoneySplit& split, const MyMoneyAccount& acc) const
 {
-  qDebug() << "SplitType";
+  Q_D(const MyMoneyTransactionFilter);
   if (acc.isIncomeExpense())
     return (int)eMyMoney::TransactionFilter::Type::All;
 
-  if (t.splitCount() == 2) {
+  if (t.splitCount() == 2 && !d->m_treatTransfersAsIncomeExpense) {
     const auto& splits = t.splits();
     const auto file = MyMoneyFile::instance();
     const auto& a = splits.at(0).id().compare(split.id()) == 0 ? acc : file->account(splits.at(0).accountId());
     const auto& b = splits.at(1).id().compare(split.id()) == 0 ? acc : file->account(splits.at(1).accountId());
-    qDebug() << "first split: " << splits.at(0).accountId() << "second split: " << splits.at(1).accountId();
 
     if (!a.isIncomeExpense() && !b.isIncomeExpense())
       return (int)eMyMoney::TransactionFilter::Type::Transfers;
@@ -627,25 +645,25 @@ eMyMoney::TransactionFilter::Validity MyMoneyTransactionFilter::validTransaction
 bool MyMoneyTransactionFilter::includesCategory(const QString& cat) const
 {
   Q_D(const MyMoneyTransactionFilter);
-  return !d->m_filterSet.singleFilter.categoryFilter || d->m_categories.contains(cat);
+  return !d->m_filterSet.testFlag(categoryFilterActive) || d->m_categories.contains(cat);
 }
 
 bool MyMoneyTransactionFilter::includesAccount(const QString& acc) const
 {
   Q_D(const MyMoneyTransactionFilter);
-  return !d->m_filterSet.singleFilter.accountFilter || d->m_accounts.contains(acc);
+  return !d->m_filterSet.testFlag(accountFilterActive) || d->m_accounts.contains(acc);
 }
 
 bool MyMoneyTransactionFilter::includesPayee(const QString& pye) const
 {
   Q_D(const MyMoneyTransactionFilter);
-  return !d->m_filterSet.singleFilter.payeeFilter || d->m_payees.contains(pye);
+  return !d->m_filterSet.testFlag(payeeFilterActive) || d->m_payees.contains(pye);
 }
 
 bool MyMoneyTransactionFilter::includesTag(const QString& tag) const
 {
   Q_D(const MyMoneyTransactionFilter);
-  return !d->m_filterSet.singleFilter.tagFilter || d->m_tags.contains(tag);
+  return !d->m_filterSet.testFlag(tagFilterActive) || d->m_tags.contains(tag);
 }
 
 bool MyMoneyTransactionFilter::dateFilter(QDate& from, QDate& to) const
@@ -653,7 +671,7 @@ bool MyMoneyTransactionFilter::dateFilter(QDate& from, QDate& to) const
   Q_D(const MyMoneyTransactionFilter);
   from = d->m_fromDate;
   to = d->m_toDate;
-  return d->m_filterSet.singleFilter.dateFilter == 1;
+  return d->m_filterSet.testFlag(dateFilterActive);
 }
 
 bool MyMoneyTransactionFilter::amountFilter(MyMoneyMoney& from, MyMoneyMoney& to) const
@@ -661,7 +679,7 @@ bool MyMoneyTransactionFilter::amountFilter(MyMoneyMoney& from, MyMoneyMoney& to
   Q_D(const MyMoneyTransactionFilter);
   from = d->m_fromAmount;
   to = d->m_toAmount;
-  return d->m_filterSet.singleFilter.amountFilter == 1;
+  return d->m_filterSet.testFlag(amountFilterActive);
 }
 
 bool MyMoneyTransactionFilter::numberFilter(QString& from, QString& to) const
@@ -669,13 +687,13 @@ bool MyMoneyTransactionFilter::numberFilter(QString& from, QString& to) const
   Q_D(const MyMoneyTransactionFilter);
   from = d->m_fromNr;
   to = d->m_toNr;
-  return d->m_filterSet.singleFilter.nrFilter == 1;
+  return d->m_filterSet.testFlag(nrFilterActive);
 }
 
 bool MyMoneyTransactionFilter::payees(QStringList& list) const
 {
   Q_D(const MyMoneyTransactionFilter);
-  auto result = d->m_filterSet.singleFilter.payeeFilter;
+  auto result = d->m_filterSet.testFlag(payeeFilterActive);
 
   if (result) {
     QHashIterator<QString, QString> it_payee(d->m_payees);
@@ -690,7 +708,7 @@ bool MyMoneyTransactionFilter::payees(QStringList& list) const
 bool MyMoneyTransactionFilter::tags(QStringList& list) const
 {
   Q_D(const MyMoneyTransactionFilter);
-  auto result = d->m_filterSet.singleFilter.tagFilter;
+  auto result = d->m_filterSet.testFlag(tagFilterActive);
 
   if (result) {
     QHashIterator<QString, QString> it_tag(d->m_tags);
@@ -705,7 +723,7 @@ bool MyMoneyTransactionFilter::tags(QStringList& list) const
 bool MyMoneyTransactionFilter::accounts(QStringList& list) const
 {
   Q_D(const MyMoneyTransactionFilter);
-  auto result = d->m_filterSet.singleFilter.accountFilter;
+  auto result = d->m_filterSet.testFlag(accountFilterActive);
 
   if (result) {
     QHashIterator<QString, QString> it_account(d->m_accounts);
@@ -721,7 +739,7 @@ bool MyMoneyTransactionFilter::accounts(QStringList& list) const
 bool MyMoneyTransactionFilter::categories(QStringList& list) const
 {
   Q_D(const MyMoneyTransactionFilter);
-  auto result = d->m_filterSet.singleFilter.categoryFilter;
+  auto result = d->m_filterSet.testFlag(categoryFilterActive);
 
   if (result) {
     QHashIterator<QString, QString> it_category(d->m_categories);
@@ -736,7 +754,7 @@ bool MyMoneyTransactionFilter::categories(QStringList& list) const
 bool MyMoneyTransactionFilter::types(QList<int>& list) const
 {
   Q_D(const MyMoneyTransactionFilter);
-  auto result = d->m_filterSet.singleFilter.typeFilter;
+  auto result = d->m_filterSet.testFlag(typeFilterActive);
 
   if (result) {
     QHashIterator<int, QString> it_type(d->m_types);
@@ -751,7 +769,7 @@ bool MyMoneyTransactionFilter::types(QList<int>& list) const
 bool MyMoneyTransactionFilter::states(QList<int>& list) const
 {
   Q_D(const MyMoneyTransactionFilter);
-  auto result = d->m_filterSet.singleFilter.stateFilter;
+  auto result = d->m_filterSet.testFlag(stateFilterActive);
 
   if (result) {
     QHashIterator<int, QString> it_state(d->m_states);
@@ -766,7 +784,7 @@ bool MyMoneyTransactionFilter::states(QList<int>& list) const
 bool MyMoneyTransactionFilter::validities(QList<int>& list) const
 {
   Q_D(const MyMoneyTransactionFilter);
-  auto result = d->m_filterSet.singleFilter.validityFilter;
+  auto result = d->m_filterSet.testFlag(validityFilterActive);
 
   if (result) {
     QHashIterator<int, QString> it_validity(d->m_validity);
@@ -781,7 +799,7 @@ bool MyMoneyTransactionFilter::validities(QList<int>& list) const
 bool MyMoneyTransactionFilter::firstType(int&i) const
 {
   Q_D(const MyMoneyTransactionFilter);
-  auto result = d->m_filterSet.singleFilter.typeFilter;
+  auto result = d->m_filterSet.testFlag(typeFilterActive);
 
   if (result) {
     QHashIterator<int, QString> it_type(d->m_types);
@@ -796,7 +814,7 @@ bool MyMoneyTransactionFilter::firstType(int&i) const
 bool MyMoneyTransactionFilter::firstState(int&i) const
 {
   Q_D(const MyMoneyTransactionFilter);
-  auto result = d->m_filterSet.singleFilter.stateFilter;
+  auto result = d->m_filterSet.testFlag(stateFilterActive);
 
   if (result) {
     QHashIterator<int, QString> it_state(d->m_states);
@@ -811,7 +829,7 @@ bool MyMoneyTransactionFilter::firstState(int&i) const
 bool MyMoneyTransactionFilter::firstValidity(int&i) const
 {
   Q_D(const MyMoneyTransactionFilter);
-  auto result = d->m_filterSet.singleFilter.validityFilter;
+  auto result = d->m_filterSet.testFlag(validityFilterActive);
 
   if (result) {
     QHashIterator<int, QString> it_validity(d->m_validity);
@@ -827,7 +845,7 @@ bool MyMoneyTransactionFilter::textFilter(QRegExp& exp) const
 {
   Q_D(const MyMoneyTransactionFilter);
   exp = d->m_text;
-  return d->m_filterSet.singleFilter.textFilter == 1;
+  return d->m_filterSet.testFlag(textFilterActive);
 }
 
 bool MyMoneyTransactionFilter::isInvertingText() const
