@@ -74,7 +74,7 @@ typedef enum  {
 class OFXImporter::Private
 {
 public:
-  Private() : m_valid(false), m_preferName(PreferId), m_uniqueIdSource(UniqueIdUnknown), m_walletIsOpen(false), m_statusDlg(0), m_wallet(0),
+  Private() : m_valid(false), m_preferName(PreferId), m_uniqueIdSource(UniqueIdUnknown), m_walletIsOpen(false), m_invertAmount(false), m_fixBuySellSignage(false), m_statusDlg(0), m_wallet(0),
               m_updateStartDate(QDate(1900,1,1)), m_timestampOffset(0) {}
 
   bool m_valid;
@@ -85,6 +85,8 @@ public:
   } m_preferName;
   UniqueTransactionIdSource  m_uniqueIdSource;
   bool m_walletIsOpen;
+  bool m_invertAmount;
+  bool m_fixBuySellSignage;
   QList<MyMoneyStatement> m_statementlist;
   QList<MyMoneyStatement::Security> m_securitylist;
   QString m_fatalerror;
@@ -183,6 +185,8 @@ void OFXImporter::slotImportFile()
   d->m_preferName = static_cast<OFXImporter::Private::NamePreference>(option->m_preferName->currentIndex());
   d->m_uniqueIdSource = static_cast<UniqueTransactionIdSource>(option->m_uniqueIdSource->currentIndex());
   d->m_timestampOffset = d->constructTimeOffset(option->m_timestampOffset, option->m_timestampOffsetSign);
+  d->m_invertAmount = option->m_invertAmount->isChecked();
+  d->m_fixBuySellSignage = option->m_fixBuySellSignage->isChecked();
 
   if (url.isValid()) {
     const QString filename(url.toLocalFile());
@@ -284,6 +288,27 @@ bool OFXImporter::import(const QString& filename)
   ofx_set_security_cb(ctx, ofxSecurityCallback, this);
   ofx_set_status_cb(ctx, ofxStatusCallback, this);
   qDebug("process data");
+
+#ifdef IS_APPIMAGE
+  // libofx needs to know where to pick up the DTD
+  // files when running in APPIMAGE mode
+  const char* env = getenv("APPDIR");
+  if (env && *env) {
+    QByteArray dir = env;
+    dir.append("/usr/share/libofx/dtd/");
+    qDebug() << "Set DTD dir to" << dir;
+    libofx_set_dtd_dir(ctx, dir.data());
+  }
+#endif
+
+#ifdef Q_OS_MACOS
+  // libofx needs to know where to pick up the DTD
+  // files when running on MacOS
+  QByteArray dir("/Applications/kmymoney.app/Contents/Resources/libofx/dtd/");
+  qDebug() << "Set DTD dir to" << dir;
+  libofx_set_dtd_dir(ctx, dir.data());
+#endif
+
   libofx_proc_file(ctx, filename_deep, AUTODETECT);
   qDebug("process data done");
   libofx_free_context(ctx);
@@ -336,8 +361,98 @@ int OFXImporter::ofxTransactionCallback(struct OfxTransactionData data, void * p
     }
   }
 
+  bool unhandledtype = false;
+  QString type;
+
+  if (data.invtransactiontype_valid) {
+    switch (data.invtransactiontype) {
+      case OFX_BUYDEBT:
+      case OFX_BUYMF:
+      case OFX_BUYOPT:
+      case OFX_BUYOTHER:
+      case OFX_BUYSTOCK:
+        t.m_eAction = eMyMoney::Transaction::Action::Buy;
+        break;
+      case OFX_REINVEST:
+        t.m_eAction = eMyMoney::Transaction::Action::ReinvestDividend;
+        break;
+      case OFX_SELLDEBT:
+      case OFX_SELLMF:
+      case OFX_SELLOPT:
+      case OFX_SELLOTHER:
+      case OFX_SELLSTOCK:
+        t.m_eAction = eMyMoney::Transaction::Action::Sell;
+        break;
+      case OFX_INCOME:
+        t.m_eAction = eMyMoney::Transaction::Action::CashDividend;
+        // NOTE: With CashDividend, the amount of the dividend should
+        // be in data.amount.  Since I've never seen an OFX file with
+        // cash dividends, this is an assumption on my part. (acejones)
+        break;
+
+        //
+        // These types are all not handled.  We will generate a warning for them.
+        //
+      case OFX_CLOSUREOPT:
+        unhandledtype = true;
+        type = QStringLiteral("CLOSUREOPT (Close a position for an option)");
+        break;
+      case OFX_INVEXPENSE:
+        unhandledtype = true;
+        type = QStringLiteral("INVEXPENSE (Misc investment expense that is associated with a specific security)");
+        break;
+      case OFX_JRNLFUND:
+        unhandledtype = true;
+        type = QStringLiteral("JRNLFUND (Journaling cash holdings between subaccounts within the same investment account)");
+        break;
+      case OFX_MARGININTEREST:
+        unhandledtype = true;
+        type = QStringLiteral("MARGININTEREST (Margin interest expense)");
+        break;
+      case OFX_RETOFCAP:
+        unhandledtype = true;
+        type = QStringLiteral("RETOFCAP (Return of capital)");
+        break;
+      case OFX_SPLIT:
+        unhandledtype = true;
+        type = QStringLiteral("SPLIT (Stock or mutial fund split)");
+        break;
+      case OFX_TRANSFER:
+        unhandledtype = true;
+        type = QStringLiteral("TRANSFER (Transfer holdings in and out of the investment account)");
+        break;
+      default:
+        unhandledtype = true;
+        type = QString("UNKNOWN %1").arg(data.invtransactiontype);
+        break;
+    }
+  } else
+    t.m_eAction = eMyMoney::Transaction::Action::None;
+
+  t.m_shares = MyMoneyMoney();
+  if (data.units_valid) {
+    t.m_shares = MyMoneyMoney(data.units, 100000).reduce();
+  }
+
+  t.m_amount = MyMoneyMoney();
   if (data.amount_valid) {
     t.m_amount = MyMoneyMoney(data.amount, 1000);
+
+    if (pofx->d->m_fixBuySellSignage) {
+      if (t.m_eAction == eMyMoney::Transaction::Action::Buy
+          || t.m_eAction == eMyMoney::Transaction::Action::ReinvestDividend) {
+        t.m_amount = -t.m_amount.abs();
+        t.m_shares = t.m_shares.abs();
+      }
+      else if (t.m_eAction == eMyMoney::Transaction::Action::Sell) {
+        t.m_amount = t.m_amount.abs();
+        t.m_shares = -t.m_shares.abs();
+      }
+    }
+
+    if (pofx->d->m_invertAmount) {
+      t.m_amount = -t.m_amount;
+    }
   }
 
   if (data.check_number_valid) {
@@ -472,11 +587,6 @@ int OFXImporter::ofxTransactionCallback(struct OfxTransactionData data, void * p
     }
   }
 
-  t.m_shares = MyMoneyMoney();
-  if (data.units_valid) {
-    t.m_shares = MyMoneyMoney(data.units, 100000).reduce();
-  }
-
   t.m_price = MyMoneyMoney();
   if (data.unitprice_valid) {
     t.m_price = MyMoneyMoney(data.unitprice, 100000).reduce();
@@ -491,74 +601,6 @@ int OFXImporter::ofxTransactionCallback(struct OfxTransactionData data, void * p
     t.m_fees += MyMoneyMoney(data.commission, 1000).reduce();
   }
 
-  bool unhandledtype = false;
-  QString type;
-
-  if (data.invtransactiontype_valid) {
-    switch (data.invtransactiontype) {
-      case OFX_BUYDEBT:
-      case OFX_BUYMF:
-      case OFX_BUYOPT:
-      case OFX_BUYOTHER:
-      case OFX_BUYSTOCK:
-        t.m_eAction = eMyMoney::Transaction::Action::Buy;
-        break;
-      case OFX_REINVEST:
-        t.m_eAction = eMyMoney::Transaction::Action::ReinvestDividend;
-        break;
-      case OFX_SELLDEBT:
-      case OFX_SELLMF:
-      case OFX_SELLOPT:
-      case OFX_SELLOTHER:
-      case OFX_SELLSTOCK:
-        t.m_eAction = eMyMoney::Transaction::Action::Sell;
-        break;
-      case OFX_INCOME:
-        t.m_eAction = eMyMoney::Transaction::Action::CashDividend;
-        // NOTE: With CashDividend, the amount of the dividend should
-        // be in data.amount.  Since I've never seen an OFX file with
-        // cash dividends, this is an assumption on my part. (acejones)
-        break;
-
-        //
-        // These types are all not handled.  We will generate a warning for them.
-        //
-      case OFX_CLOSUREOPT:
-        unhandledtype = true;
-        type = QStringLiteral("CLOSUREOPT (Close a position for an option)");
-        break;
-      case OFX_INVEXPENSE:
-        unhandledtype = true;
-        type = QStringLiteral("INVEXPENSE (Misc investment expense that is associated with a specific security)");
-        break;
-      case OFX_JRNLFUND:
-        unhandledtype = true;
-        type = QStringLiteral("JRNLFUND (Journaling cash holdings between subaccounts within the same investment account)");
-        break;
-      case OFX_MARGININTEREST:
-        unhandledtype = true;
-        type = QStringLiteral("MARGININTEREST (Margin interest expense)");
-        break;
-      case OFX_RETOFCAP:
-        unhandledtype = true;
-        type = QStringLiteral("RETOFCAP (Return of capital)");
-        break;
-      case OFX_SPLIT:
-        unhandledtype = true;
-        type = QStringLiteral("SPLIT (Stock or mutial fund split)");
-        break;
-      case OFX_TRANSFER:
-        unhandledtype = true;
-        type = QStringLiteral("TRANSFER (Transfer holdings in and out of the investment account)");
-        break;
-      default:
-        unhandledtype = true;
-        type = QString("UNKNOWN %1").arg(data.invtransactiontype);
-        break;
-    }
-  } else
-    t.m_eAction = eMyMoney::Transaction::Action::None;
-
   // In the case of investment transactions, the 'total' is supposed to the total amount
   // of the transaction.  units * unitprice +/- commission.  Easy, right?  Sadly, it seems
   // some ofx creators do not follow this in all circumstances.  Therefore, we have to double-
@@ -567,7 +609,7 @@ int OFXImporter::ofxTransactionCallback(struct OfxTransactionData data, void * p
 #if 0
   // Even more sadly, this logic is BROKEN.  It consistently results in bogus total
   // values, because of rounding errors in the price.  A more through solution would
-  // be to test if the comission alone is causing a discrepency, and adjust in that case.
+  // be to test if the commission alone is causing a discrepancy, and adjust in that case.
 
   if (data.invtransactiontype_valid && data.unitprice_valid) {
     double proper_total = t.m_dShares * data.unitprice + t.m_moneyFees;
@@ -826,6 +868,16 @@ MyMoneyKeyValueContainer OFXImporter::onlineBankingSettings(const MyMoneyKeyValu
     } else {
       kvp.setValue(QStringLiteral("kmmofx-timestampOffset"), QString::number(offset));
     }
+    if (d->m_statusDlg->m_invertAmount->isChecked()) {
+      kvp.setValue(QStringLiteral("kmmofx-invertamount"), QStringLiteral("yes"));
+    } else {
+      kvp.deletePair(QStringLiteral("kmmofx-invertamount"));
+    }
+    if (d->m_statusDlg->m_fixBuySellSignage->isChecked()) {
+      kvp.setValue(QStringLiteral("kmmofx-fixbuysellsignage"), QStringLiteral("yes"));
+    } else {
+      kvp.deletePair(QStringLiteral("kmmofx-fixbuysellsignage"));
+    }
     // get rid of pre 4.6 values
     kvp.deletePair(QStringLiteral("kmmofx-preferPayeeid"));
   }
@@ -868,7 +920,7 @@ bool OFXImporter::updateAccount(const MyMoneyAccount& acc, bool moreAccounts)
       connect(dlg.data(), &KOfxDirectConnectDlg::statementReady, this, static_cast<void (OFXImporter::*)(const QString &)>(&OFXImporter::slotImportFile));
 
       // get the date of the earliest transaction that we are interested in
-      // from the settings for this account
+      // as well as other parameters from the settings for this account
       MyMoneyKeyValueContainer settings = acc.onlineBankingSettings();
       if (!settings.value(QStringLiteral("provider")).isEmpty()) {
         if ((settings.value(QStringLiteral("kmmofx-todayMinus")).toInt() != 0) && !settings.value(QStringLiteral("kmmofx-numRequestDays")).isEmpty()) {
@@ -885,6 +937,9 @@ bool OFXImporter::updateAccount(const MyMoneyAccount& acc, bool moreAccounts)
           //kDebug(0) << "start date = today - 2 months";
           d->m_updateStartDate = QDate::currentDate().addMonths(-2);
         }
+
+        d->m_invertAmount = settings.value("kmmofx-invertamount").toLower() == QStringLiteral("yes");
+        d->m_fixBuySellSignage= settings.value("kmmofx-fixbuysellsignage").toLower() == QStringLiteral("yes");
       }
       d->m_timestampOffset = settings.value("kmmofx-timestampOffset").toInt();
       //kDebug(0) << "ofx plugin: account" << acc.name() << "earliest transaction date to process =" << qPrintable(d->m_updateStartDate.toString(Qt::ISODate));
