@@ -40,7 +40,7 @@
 #include "mymoneyenums.h"
 
 /*
- * CENTURY_BREAK is used to identfy the century for a two digit year
+ * CENTURY_BREAK is used to identify the century for a two digit year
  *
  * if yr is < CENTURY_BREAK it is in 2000
  * if yr is >= CENTURY_BREAK it is in 1900
@@ -160,7 +160,7 @@ void MyMoneyQifProfile::clear()
   m_valueMode = "";
   m_filterScriptImport = "";
   m_filterScriptExport = "";
-  m_filterFileType = "*.qif";
+  m_filterFileType = "*.qif *.QIF";
 
   m_decimal.clear();
   m_decimal['$'] =
@@ -426,7 +426,7 @@ const QString MyMoneyQifProfile::date(const QDate& datein) const
         }
         break;
       } else {
-        throw MYMONEYEXCEPTION("Invalid char in QifProfile date field");
+        throw MYMONEYEXCEPTION_CSTRING("Invalid char in QifProfile date field");
       }
       delim = 0;
     } else {
@@ -813,7 +813,7 @@ void MyMoneyQifProfile::autoDetect(const QStringList& lines)
   QStringList::const_iterator it;
   int datesScanned = 0;
   // section: used to switch between different QIF sections,
-  // because the Record identifiers are ambigous between sections
+  // because the Record identifiers are ambiguous between sections
   // eg. in transaction records, T identifies a total amount, in
   // account sections it's the type.
   //
