@@ -120,7 +120,7 @@ public:
     KConfigGroup grp = config->group("Last Use Settings");
     ui->m_tab->setCurrentIndex(grp.readEntry("KForecastView_LastType", 0));
 
-    ui->m_forecastButton->setIcon(Icons::get(Icon::ViewForecast));
+    ui->m_forecastButton->setIcon(Icons::get(Icon::Forecast));
 
     q->connect(ui->m_tab, &QTabWidget::currentChanged, q, &KForecastView::slotTabChanged);
 
@@ -658,9 +658,11 @@ public:
           QString::number(ui->m_forecastDays->value()) + ';' +
           QString::number(ui->m_tab->width()) + ';' +
           QString::number(ui->m_tab->height());
-       const auto variantReport = reportsPlugin->requestData(args, eWidgetPlugin::WidgetType::NetWorthForecastWithArgs);
+      const auto variantReport = reportsPlugin->requestData(args, eWidgetPlugin::WidgetType::NetWorthForecastWithArgs);
       if (!variantReport.isNull())
         m_forecastChart = variantReport.value<QWidget *>();
+      else
+        m_forecastChart = new QLabel(i18n("No data provided by reports plugin for this chart."));
     } else {
         m_forecastChart = new QLabel(i18n("Enable reports plugin to see this chart."));
     }
@@ -898,8 +900,6 @@ public:
 
   void updateDetailed(QTreeWidgetItem *item)
   {
-    QString amount;
-    QString vAmount;
     MyMoneyMoney vAmountMM;
     const auto file = MyMoneyFile::instance();
 
