@@ -825,7 +825,7 @@ void QueryTable::constructTransactionTable()
               qA[ctFees] = (n0 + value).toString();
             }
             // we don't add qA here for a loan transaction. we'll add one
-            // qA afer all of the split components have been processed.
+            // qA after all of the split components have been processed.
             // (see below)
 
           }
@@ -1601,12 +1601,7 @@ void QueryTable::constructAccountTable()
           qaccountrow[ctValue] = (netprice * shares).convert(fraction).toString();
           qaccountrow[ctShares] = shares.toString();
 
-          QString iid = account.institutionId();
-
-          // If an account does not have an institution, get it from the top-parent.
-          if (iid.isEmpty() && !account.isTopLevel())
-            iid = account.topParent().institutionId();
-
+          const auto iid = account.institutionId();
           if (iid.isEmpty())
             qaccountrow[ctInstitution] = i18nc("No institution", "None");
           else
