@@ -11,6 +11,7 @@
                            Kevin Tambascio <ktambascio@users.sourceforge.net>
                            Ace Jones <ace.j@hotpop.com>
                            (C) 2017 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+                           2018 Michael Kiefer <Michael-Kiefer@web.de>
  ***************************************************************************/
 
 /***************************************************************************
@@ -44,10 +45,9 @@
 #include <QFileDialog>
 #include <QLocale>
 #include <QTextCodec>
-#include <QPrintDialog>
 #include <QMenu>
 #include <QPointer>
-#include <QPrinter>
+#include <QWheelEvent>
 #ifdef ENABLE_WEBENGINE
 #include <QWebEngineView>
 #else
@@ -84,6 +84,7 @@
 #include "reporttable.h"
 #include "reportcontrolimpl.h"
 #include "mymoneyenums.h"
+#include "kmm_printer.h"
 
 using namespace reports;
 using namespace eMyMoney;
@@ -114,7 +115,6 @@ private:
   reports::KReportChartView *m_chartView;
   ReportControl             *m_control;
   QVBoxLayout               *m_layout;
-  QPrinter                  *m_currentPrinter;
   MyMoneyReport m_report;
   bool m_deleteMe;
   bool m_chartEnabled;
@@ -138,7 +138,7 @@ public:
   void print();
   void toggleChart();
   /**
-   * Updates information about ploted chart in report's data
+   * Updates information about plotted chart in report's data
    */
   void updateDataRange();
   void copyToClipboard();
@@ -159,6 +159,10 @@ public:
   }
   void showEvent(QShowEvent * event) final override;
   void loadTab();
+
+protected:
+  void wheelEvent(QWheelEvent *event) override;
+
 };
 
 /**
@@ -198,7 +202,6 @@ KReportTab::KReportTab(QTabWidget* parent, const MyMoneyReport& report, const KR
     m_chartView(new KReportChartView(this)),
     m_control(new ReportControl(this)),
     m_layout(new QVBoxLayout(this)),
-    m_currentPrinter(nullptr),
     m_report(report),
     m_deleteMe(false),
     m_chartEnabled(false),
@@ -265,7 +268,7 @@ KReportTab::KReportTab(QTabWidget* parent, const MyMoneyReport& report, const KR
     m_control->ui->buttonDelete->setEnabled(false);
 
   int tabNr = parent->addTab(this,
-                         Icons::get(Icon::Spreadsheet),
+                         Icons::get(Icon::Report),
                          report.name());
   parent->setTabEnabled(tabNr, true);
   parent->setCurrentIndex(tabNr);
@@ -279,22 +282,52 @@ KReportTab::~KReportTab()
   delete m_table;
 }
 
+
+void KReportTab::wheelEvent(QWheelEvent* event)
+{
+  // Zoom text on Ctrl + Scroll
+  if (event->modifiers() & Qt::CTRL) {
+    if (!m_showingChart) {
+      qreal factor = m_tableView->zoomFactor();
+      if (event->delta() > 0)
+        factor += 0.1;
+      else if (event->delta() < 0)
+        factor -= 0.1;
+      m_tableView->setZoomFactor(factor);
+      event->accept();
+      return;
+    }
+  }
+}
+
+
 void KReportTab::print()
 {
   if (m_tableView) {
-    m_currentPrinter = new QPrinter();
-    QPointer<QPrintDialog> dialog = new QPrintDialog(m_currentPrinter, this);
-    dialog->setWindowTitle(QString());
-    if (dialog->exec() != QDialog::Accepted) {
-      delete m_currentPrinter;
-      m_currentPrinter = nullptr;
-      return;
-    }
+    auto printer = KMyMoneyPrinter::startPrint();
+    if (printer != nullptr) {
+      if (m_showingChart) {
+        QPainter painter(printer);
+        m_chartView->paint(&painter, painter.window());
+        QFont font = painter.font();
+        font.setPointSizeF(font.pointSizeF() * 0.8);
+        painter.setFont(font);
+        QLocale locale;
+        painter.drawText(0, 0, QDate::currentDate().toString(locale.dateFormat(QLocale::ShortFormat)));
+
+        /// @todo extract url from KMyMoneyApp
+        QUrl file;
+        if (file.isValid()) {
+          painter.drawText(0, painter.window().height(), file.toLocalFile());
+        }
+      } else {
     #ifdef ENABLE_WEBENGINE
-      m_tableView->page()->print(m_currentPrinter, [=] (bool) {delete m_currentPrinter; m_currentPrinter = nullptr;});
+        m_tableView->page()->print(printer, [=] (bool) {});
     #else
-      m_tableView->print(m_currentPrinter);
+        m_tableView->print(printer);
     #endif
+      }
+    }
   }
 }
 
@@ -399,14 +432,14 @@ void KReportTab::toggleChart()
 
     m_control->ui->buttonChart->setText(i18n("Report"));
     m_control->ui->buttonChart->setToolTip(i18n("Show the report version of this chart"));
-    m_control->ui->buttonChart->setIcon(Icons::get(Icon::ViewFinancialList));
+    m_control->ui->buttonChart->setIcon(Icons::get(Icon::Ledger));
   }
   m_showingChart = ! m_showingChart;
 }
 
 void KReportTab::updateDataRange()
 {
-  QList<DataDimension> grids = m_chartView->coordinatePlane()->gridDimensionsList();    // get dimmensions of ploted graph
+  QList<DataDimension> grids = m_chartView->coordinatePlane()->gridDimensionsList();    // get dimensions of plotted graph
   if (grids.isEmpty())
     return;
   QChar separator = locale().groupSeparator();
@@ -849,6 +882,19 @@ public:
       list.back().setChartType(eMyMoney::Report::ChartType::Line);
       list.back().setChartDataLabels(false);
 
+      list.push_back(MyMoneyReport(
+                       eMyMoney::Report::RowType::ExpenseIncome,
+                       static_cast<unsigned>(eMyMoney::Report::ColumnType::Months),
+                       TransactionFilter::Date::Last12Months,
+                       eMyMoney::Report::DetailLevel::Top,
+                       i18n("Income and Expenses Bar Graph"),
+                       i18n("Default Report")
+                     ));
+      list.back().setChartByDefault(true);
+      list.back().setChartType(eMyMoney::Report::ChartType::StackedBar);
+      list.back().setChartDataLabels(false);
+      list.back().setNegExpenses(true);
+
       list.push_back(MyMoneyReport(
                        eMyMoney::Report::RowType::ExpenseIncome,
                        static_cast<unsigned>(eMyMoney::Report::ColumnType::Months),
