@@ -27,6 +27,8 @@
 #include <QFile>
 #include <QTemporaryFile>
 #include <QFileDialog>
+#include <QRegularExpression>
+#include <QRegularExpressionMatch>
 
 // ----------------------------------------------------------------------------
 // KDE Includes
@@ -350,6 +352,21 @@ bool XMLStorage::saveAs()
                     QString(QLatin1String("%2 (%1);;")).arg(QStringLiteral("*.xml")).arg(i18nc("XML (Filefilter)", "XML files")) +
                     QString(QLatin1String("%2 (%1);;")).arg(QStringLiteral("*")).arg(i18nc("All files (Filefilter)", "All files")));
   dlg->setAcceptMode(QFileDialog::AcceptSave);
+  connect(dlg, &QFileDialog::filterSelected, this, [&](const QString txt) {
+    // for some reason, txt sometimes contains the filter expression only
+    // e.g. "*.xml" and in some others it contains the full text with
+    // the filter expression appended in parenthesis e.g.
+    // "KMyMoney files (*.xml)". The following logic extracts the
+    // filter and sets the default suffix based on it.
+    QRegularExpression filter(QStringLiteral("\\*\\.(?<extension>[a-z\\.]+)"));
+    const auto match = filter.match(txt);
+    if (match.hasMatch()) {
+      dlg->setDefaultSuffix(match.captured(QStringLiteral("extension")));
+    } else {
+      dlg->setDefaultSuffix(QString());
+    }
+
+  });
 
   if (dlg->exec() == QDialog::Accepted && dlg != 0) {
     QUrl newURL = dlg->selectedUrls().first();
@@ -377,7 +394,16 @@ bool XMLStorage::saveAs()
             m_encryptionKeys.append(m_additionalGpgKeys.join(QLatin1Char(',')));
           }
         }
+        // clear out any existing keys so that the new ones will be used
+        MyMoneyFileTransaction ft;
+        try {
+          MyMoneyFile::instance()->deletePair("kmm-encryption-key");
+          ft.commit();
+        } catch(MyMoneyException& e) {
+          ; // do nothing
+        }
         rc = save(newURL);
+
         appInterface()->addToRecentFiles(newURL);
         //write the directory used for this file as the default one for next time.
         appInterface()->writeLastUsedDir(newURL.toDisplayString(QUrl::RemoveFilename | QUrl::PreferLocalFile | QUrl::StripTrailingSlash));
@@ -443,6 +469,8 @@ void XMLStorage::saveToLocalFile(const QString& localFile, IMyMoneyOperationsFor
     }
   }
 
+  // Permissions to apply to new file
+  QFileDevice::Permissions fmode = QFileDevice::ReadUser | QFileDevice::WriteUser;
 
   // Create a temporary file if needed
   QString writeFile = localFile;
@@ -451,6 +479,8 @@ void XMLStorage::saveToLocalFile(const QString& localFile, IMyMoneyOperationsFor
     tmpFile.open();
     writeFile = tmpFile.fileName();
     tmpFile.close();
+    // Since file is going to be replaced, stash the original permissions so they can be restored
+    fmode = QFile::permissions(localFile);
   }
 
   /**
@@ -521,7 +551,7 @@ void XMLStorage::saveToLocalFile(const QString& localFile, IMyMoneyOperationsFor
     if (!QFile::remove(localFile) || !QFile::copy(writeFile, localFile))
       throw MYMONEYEXCEPTION(QString::fromLatin1("Failure while writing to '%1'").arg(localFile));
   }
-  QFile::setPermissions(localFile, QFileDevice::ReadUser | QFileDevice::WriteUser);
+  QFile::setPermissions(localFile, fmode);
   pWriter->setProgressCallback(0);
 }
 
