@@ -39,8 +39,8 @@
 #include <QUrlQuery>
 #include <QWheelEvent>
 #include <QPrintDialog>
+#include <QVBoxLayout>
 #include <QPrinter>
-#include <QPointer>
 #ifdef ENABLE_WEBENGINE
 #include <QWebEngineView>
 #else
@@ -51,8 +51,6 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
-#include <KChartAbstractCoordinatePlane>
-#include <KChartChart>
 #include <KLocalizedString>
 #include <KXmlGuiWindow>
 #include <KActionCollection>
@@ -128,7 +126,7 @@ public:
     m_showAllSchedules(false),
     m_needLoad(true),
     m_netWorthGraphLastValidSize(400, 300),
-    m_currentPrinter(nullptr)
+    m_scrollBarPos(0)
   {
   }
 
@@ -198,7 +196,7 @@ public:
       amountToMinBal.replace(QChar(' '), "&nbsp;");
     }
 
-    QString cellStatus, cellCounts, pathOK, pathTODO, pathNotOK;
+    QString cellStatus, pathOK, pathTODO, pathNotOK;
 
     if (KMyMoneySettings::showBalanceStatusOfOnlineAccounts()) {
       //show account's online-status
@@ -412,6 +410,7 @@ public:
 
   void loadView()
   {
+    Q_Q(KHomeView);
     m_view->setZoomFactor(KMyMoneySettings::zoomFactor());
 
     QList<MyMoneyAccount> list;
@@ -425,11 +424,9 @@ public:
       m_transactionStats = MyMoneyFile::instance()->countTransactionsWithSpecificReconciliationState();
 
       // keep current location on page
-      int scrollBarPos = 0;
-#ifdef ENABLE_WEBENGINE
-        /// @todo cannot test this
-#else
-      scrollBarPos = m_view->page()->mainFrame()->scrollBarValue(Qt::Vertical);
+      m_scrollBarPos = 0;
+#ifndef ENABLE_WEBENGINE
+      m_scrollBarPos = m_view->page()->mainFrame()->scrollBarValue(Qt::Vertical);
 #endif
 
       //clear the forecast flag so it will be reloaded
@@ -483,6 +480,8 @@ public:
             case 6:         // net worth graph over all accounts
               showNetWorthGraph();
               break;
+            case 7:         // forecast (history) - currently unused
+              break;
             case 8:         // assets and liabilities
               showAssetsLiabilities();
               break;
@@ -492,8 +491,6 @@ public:
             case 10:         // cash flow summary
               showCashFlowSummary();
               break;
-
-
           }
           m_html += "<div class=\"gap\">&nbsp;</div>\n";
         }
@@ -507,13 +504,11 @@ public:
 
       m_view->setHtml(m_html, QUrl("file://"));
 
-      if (scrollBarPos) {
-#ifdef ENABLE_WEBENGINE
-        /// @todo cannot test this
-#else
-        m_view->page()->mainFrame()->setScrollBarValue(Qt::Vertical, scrollBarPos);
-#endif
+#ifndef ENABLE_WEBENGINE
+      if (m_scrollBarPos) {
+        QMetaObject::invokeMethod(q, "slotAdjustScrollPos", Qt::QueuedConnection);
       }
+#endif
     }
   }
 
@@ -800,7 +795,7 @@ public:
           MyMoneySplit sp = t.splitByAccount(acc.id(), true);
 
           QString pathEnter = QPixmapToDataUri(Icons::get(Icon::KeyEnter).pixmap(QSize(16,16)));
-          QString pathSkip = QPixmapToDataUri(Icons::get(Icon::MediaSkipForward).pixmap(QSize(16,16)));
+          QString pathSkip = QPixmapToDataUri(Icons::get(Icon::SkipForward).pixmap(QSize(16, 16)));
 
           //show payment date
           tmp = QString("<td>") +
@@ -947,13 +942,13 @@ public:
       m_html += "</td>";
 
       if (KMyMoneySettings::showCountOfUnmarkedTransactions())
-        m_html += QString("<td class=\"center\">!M</td>");
+        m_html += QString("<td class=\"center\">%1</td>").arg(i18nc("Header not marked", "!M"));
 
       if (KMyMoneySettings::showCountOfClearedTransactions())
-        m_html += QString("<td class=\"center\">C</td>");
+        m_html += QString("<td class=\"center\">%1</td>").arg(i18nc("Header cleared", "C"));
 
       if (KMyMoneySettings::showCountOfNotReconciledTransactions())
-        m_html += QString("<td class=\"center\">!R</td>");
+        m_html += QString("<td class=\"center\">%1</td>").arg(i18nc("Header not reconciled", "!R"));
 
       if (KMyMoneySettings::showDateOfLastReconciliation())
         m_html += QString("<td>%1</td>").arg(i18n("Last Reconciled"));
@@ -1050,7 +1045,7 @@ public:
         beginDay = m_forecast.accountsCycle();
 
       // Now output header
-      m_html += QString("<div class=\"shadow\"><div class=\"displayblock\"><div class=\"summaryheader\">%1</div>\n<div class=\"gap\">&nbsp;</div>\n").arg(i18n("%1 Day Forecast", m_forecast.forecastDays()));
+      m_html += QString("<div class=\"shadow\"><div class=\"displayblock\"><div class=\"summaryheader\">%1</div>\n<div class=\"gap\">&nbsp;</div>\n").arg(i18ncp("Forecast days", "%1 Day Forecast", "%1 Day Forecast", m_forecast.forecastDays()));
       m_html += "<table width=\"100%\" cellspacing=\"0\" cellpadding=\"2\" class=\"summarytable\" >";
       m_html += "<tr class=\"item\"><td class=\"left\" width=\"40%\">";
       m_html += i18n("Account");
@@ -1201,7 +1196,6 @@ public:
     QList<MyMoneyAccount> liabilities;
     MyMoneyMoney netAssets;
     MyMoneyMoney netLiabilities;
-    QString fontStart, fontEnd;
 
     MyMoneyFile* file = MyMoneyFile::instance();
     int prec = MyMoneyMoney::denomToPrec(file->baseCurrency().smallestAccountFraction());
@@ -1235,7 +1229,12 @@ public:
           case Account::Type::Loan:
             // list account if it's the last in the hierarchy or has transactions in it
             if ((*it).accountList().isEmpty() || (file->transactionCount((*it).id()) > 0)) {
-              liabilities << *it;
+	      // Add it if we are not hiding zero balance liabilities, or the balance is not zero
+              const auto value =
+		      MyMoneyFile::instance()->balance((*it).id(), QDate::currentDate());
+	      if (!(KMyMoneySettings::hideZeroBalanceLiabilities() && value.isZero())) {
+                liabilities << *it;
+              }
             }
             break;
 
@@ -1254,7 +1253,7 @@ public:
       QString statusHeader;
       if (KMyMoneySettings::showBalanceStatusOfOnlineAccounts()) {
         QString pathStatusHeader;
-        pathStatusHeader = QPixmapToDataUri(Icons::get(Icon::ViewOutbox).pixmap(QSize(16,16)));
+        pathStatusHeader = QPixmapToDataUri(Icons::get(Icon::OnlineJobOutbox).pixmap(QSize(16, 16)));
         statusHeader = QString("<img src=\"%1\" border=\"0\">").arg(pathStatusHeader);
       }
 
@@ -1425,20 +1424,22 @@ public:
 
   void showBudget()
   {
-    m_html += "<div class=\"shadow\"><div class=\"displayblock\"><div class=\"summaryheader\">" + i18n("Budget") + "</div>\n<div class=\"gap\">&nbsp;</div>\n";
-    m_html += "<table width=\"100%\" cellspacing=\"0\" cellpadding=\"2\" class=\"summarytable\" >";
+    QVariant variantReport;
 
     if (const auto reportsPlugin = pPlugins.data.value(QStringLiteral("reportsview"), nullptr)) {
-      const auto variantReport = reportsPlugin->requestData(QString(), eWidgetPlugin::WidgetType::Budget);
-      if (!variantReport.isNull())
-        m_html.append(variantReport.toString());
+      variantReport = reportsPlugin->requestData(QString(), eWidgetPlugin::WidgetType::Budget);
+    }
+
+    if (!variantReport.isNull()) {
+      m_html.append(variantReport.toString());
     } else {
+      m_html += "<div class=\"shadow\"><div class=\"displayblock\"><div class=\"summaryheader\">" + i18n("Budget") + "</div>\n<div class=\"gap\">&nbsp;</div>\n";
+      m_html += "<table width=\"100%\" cellspacing=\"0\" cellpadding=\"2\" class=\"summarytable\" >";
       m_html += QString("<tr>");
       m_html += QString("<td><center>%1</center></td>").arg(i18n("Enable reports plugin to see this chart."));
       m_html += QString("</tr>");
+      m_html += QString("</table></div></div>");
     }
-
-    m_html += QString("</table></div></div>");
   }
 
   void showCashFlowSummary()
@@ -1852,7 +1853,7 @@ public:
     * daily forecast balance of accounts
     */
   QMap<QString, dailyBalances> m_accountList;
-  QPrinter *m_currentPrinter;
+  int       m_scrollBarPos;
 };
 
 #endif
