@@ -190,7 +190,7 @@ public:
 
     ui->m_updateButton->setEnabled(false);
     ui->m_syncAddressbook->setEnabled(false);
-    #ifndef KMM_ADDRESSBOOK_FOUND
+    #ifndef ENABLE_ADDRESSBOOK
     ui->m_syncAddressbook->hide();
     #endif
     ui->matchTypeCombo->setCurrentIndex(0);
@@ -227,6 +227,8 @@ public:
     q->connect(ui->m_mergeButton,   &QAbstractButton::clicked, q, &KPayeesView::slotMergePayee);
 
     q->connect(ui->addressEdit,   &QTextEdit::textChanged, q, &KPayeesView::slotPayeeDataChanged);
+    q->connect(ui->payeecityEdit,  &QLineEdit::textChanged, q, &KPayeesView::slotPayeeDataChanged);
+    q->connect(ui->payeestateEdit,  &QLineEdit::textChanged, q, &KPayeesView::slotPayeeDataChanged);
     q->connect(ui->postcodeEdit,  &QLineEdit::textChanged, q, &KPayeesView::slotPayeeDataChanged);
     q->connect(ui->telephoneEdit, &QLineEdit::textChanged, q, &KPayeesView::slotPayeeDataChanged);
     q->connect(ui->emailEdit,     &QLineEdit::textChanged, q, &KPayeesView::slotPayeeDataChanged);
@@ -358,6 +360,8 @@ public:
   void clearItemData()
   {
     ui->addressEdit->setText(QString());
+    ui->payeecityEdit->setText(QString());
+    ui->payeestateEdit->setText(QString());
     ui->postcodeEdit->setText(QString());
     ui->telephoneEdit->setText(QString());
     ui->emailEdit->setText(QString());
@@ -563,7 +567,7 @@ public:
           }
         }
 
-        // TODO : check if we have a report that explicitively uses one of our payees
+        // TODO : check if we have a report that explicitly uses one of our payees
         //        and issue an appropriate warning
         try {
           // now loop over all transactions and reassign payee
