@@ -198,7 +198,7 @@ public:
       ui->m_scheduleTree->setSortingEnabled(false);
 
       KScheduleTreeItem *itemBills = new KScheduleTreeItem(ui->m_scheduleTree);
-      itemBills->setIcon(0, Icons::get(Icon::ViewExpense));
+      itemBills->setIcon(0, Icons::get(Icon::Expense));
       itemBills->setText(0, i18n("Bills"));
       itemBills->setData(0, KScheduleTreeItem::OrderRole, QVariant("0"));
       itemBills->setFirstColumnSpanned(true);
@@ -207,21 +207,21 @@ public:
       bold.setBold(true);
       itemBills->setFont(0, bold);
       KScheduleTreeItem *itemDeposits = new KScheduleTreeItem(ui->m_scheduleTree);
-      itemDeposits->setIcon(0, Icons::get(Icon::ViewIncome));
+      itemDeposits->setIcon(0, Icons::get(Icon::Income));
       itemDeposits->setText(0, i18n("Deposits"));
       itemDeposits->setData(0, KScheduleTreeItem::OrderRole, QVariant("1"));
       itemDeposits->setFirstColumnSpanned(true);
       itemDeposits->setFlags(Qt::ItemIsEnabled);
       itemDeposits->setFont(0, bold);
       KScheduleTreeItem *itemLoans = new KScheduleTreeItem(ui->m_scheduleTree);
-      itemLoans->setIcon(0, Icons::get(Icon::ViewLoan));
+      itemLoans->setIcon(0, Icons::get(Icon::Loan));
       itemLoans->setText(0, i18n("Loans"));
       itemLoans->setData(0, KScheduleTreeItem::OrderRole, QVariant("2"));
       itemLoans->setFirstColumnSpanned(true);
       itemLoans->setFlags(Qt::ItemIsEnabled);
       itemLoans->setFont(0, bold);
       KScheduleTreeItem *itemTransfers = new KScheduleTreeItem(ui->m_scheduleTree);
-      itemTransfers->setIcon(0, Icons::get(Icon::ViewFinancialTransfer));
+      itemTransfers->setIcon(0, Icons::get(Icon::Transaction));
       itemTransfers->setText(0, i18n("Transfers"));
       itemTransfers->setData(0, KScheduleTreeItem::OrderRole, QVariant("3"));
       itemTransfers->setFirstColumnSpanned(true);
@@ -352,14 +352,14 @@ public:
     item->setData(0, KScheduleTreeItem::OrderRole, schedule.name());
     if (!schedule.isFinished()) {
       if (schedule.isOverdue()) {
-        item->setIcon(0, Icons::get(Icon::ViewUpcominEvents));
+        item->setIcon(0, Icons::get(Icon::UpcomingEvents));
         QBrush brush = item->foreground(0);
         brush.setColor(Qt::red);
         for (int i = 0; i < ui->m_scheduleTree->columnCount(); ++i) {
           item->setForeground(i, brush);
         }
       } else {
-        item->setIcon(0, Icons::get(Icon::ViewCalendarDay));
+        item->setIcon(0, Icons::get(Icon::CalendarDay));
       }
     } else {
       item->setIcon(0, Icons::get(Icon::DialogClose));
