@@ -1,5 +1,5 @@
 /*
- * Copyright 2010-2017  Thomas Baumgart <tbaumgart@kde.org>
+ * Copyright 2010-2019  Thomas Baumgart <tbaumgart@kde.org>
  * Copyright 2017-2018  Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
@@ -28,7 +28,6 @@
 #include <QToolButton>
 #include <QFrame>
 #include <QLocale>
-#include <QDebug>
 
 // ----------------------------------------------------------------------------
 // KDE Includes
@@ -41,12 +40,30 @@
 
 #include "amountvalidator.h"
 #include "kmymoneycalculator.h"
-#include "mymoneymoney.h"
 #include "mymoneysecurity.h"
 #include "icons/icons.h"
 
 using namespace Icons;
 
+class AmountEditHelper
+{
+public:
+  AmountEditHelper() : q(nullptr) {}
+  ~AmountEditHelper() { delete q; }
+  AmountEdit *q;
+};
+
+Q_GLOBAL_STATIC(AmountEditHelper, s_globalAmountEdit)
+
+AmountEdit* AmountEdit::global()
+{
+  if (!s_globalAmountEdit()->q) {
+    s_globalAmountEdit()->q = new AmountEdit(0, 2);
+  }
+
+  return s_globalAmountEdit()->q;
+}
+
 class AmountEditPrivate
 {
   Q_DISABLE_COPY(AmountEditPrivate)
@@ -84,10 +101,11 @@ public:
     int btnSize = q->sizeHint().height() - 5;
 
     m_calculatorButton = new QToolButton(q);
-    m_calculatorButton->setIcon(Icons::get(Icon::AccessoriesCalculator));
+    m_calculatorButton->setIcon(Icons::get(Icon::Calculator));
     m_calculatorButton->setCursor(Qt::ArrowCursor);
     m_calculatorButton->setStyleSheet("QToolButton { border: none; padding: 2px}");
     m_calculatorButton->setFixedSize(btnSize, btnSize);
+    m_calculatorButton->setFocusPolicy(Qt::ClickFocus);
     m_calculatorButton->show();
 
     int frameWidth = q->style()->pixelMetric(QStyle::PM_DefaultFrameWidth);
@@ -143,10 +161,11 @@ public:
     if (p.x() + w > QApplication::desktop()->width())
       p.setX(p.x() + q->width() - w);
 
+    m_calculatorFrame->show();
+
     QRect r = m_calculator->geometry();
     r.moveTopLeft(p);
     m_calculatorFrame->setGeometry(r);
-    m_calculatorFrame->show();
     m_calculator->setFocus();
   }
 
@@ -165,11 +184,8 @@ public:
    *
    * @sa setStandardPrecision()
    */
-  static int standardPrecision;
 };
 
-int AmountEditPrivate::standardPrecision = 2;
-
 AmountEdit::AmountEdit(QWidget *parent, const int prec) :
   QLineEdit(parent),
   d_ptr(new AmountEditPrivate(this))
@@ -177,7 +193,7 @@ AmountEdit::AmountEdit(QWidget *parent, const int prec) :
   Q_D(AmountEdit);
   d->m_prec = prec;
   if (prec < -1 || prec > 20) {
-    d->m_prec = AmountEditPrivate::standardPrecision;
+    d->m_prec = AmountEdit::global()->standardPrecision();
   }
   d->init();
 }
@@ -200,10 +216,15 @@ AmountEdit::~AmountEdit()
 void AmountEdit::setStandardPrecision(int prec)
 {
   if (prec >= 0 && prec < 20) {
-    AmountEditPrivate::standardPrecision = prec;
+    global()->d_ptr->m_prec = prec;
   }
 }
 
+int AmountEdit::standardPrecision()
+{
+  return global()->d_ptr->m_prec;
+}
+
 
 void AmountEdit::resizeEvent(QResizeEvent* event)
 {
@@ -270,6 +291,12 @@ void AmountEdit::keyPressEvent(QKeyEvent* event)
         break;
 
     default:
+      // in case all text is selected and the user presses the decimal point
+      // we fill the widget with the leading "0". The outcome of this will be
+      // that the widget then contains "0.".
+      if ((event->key() == QLocale().decimalPoint()) && (selectedText() == text())) {
+        QLineEdit::setText(QLatin1String("0"));
+      }
       QLineEdit::keyPressEvent(event);
       break;
   }
