@@ -1,25 +1,20 @@
-/***************************************************************************
-                          kmymoneycalculator.cpp  -  description
-                             -------------------
-    begin                : Sat Oct 19 2002
-    copyright            : (C) 2000-2002 by Michael Edwardes
-    email                : mte@users.sourceforge.net
-                           Javier Campos Morales <javi_c@users.sourceforge.net>
-                           Felix Rodriguez <frodriguez@users.sourceforge.net>
-                           John C <thetacoturtle@users.sourceforge.net>
-                           Thomas Baumgart <ipwizard@users.sourceforge.net>
-                           Kevin Tambascio <ktambascio@users.sourceforge.net>
-                           (C) 2017 by Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+ * Copyright 2002-2017  Thomas Baumgart <tbaumgart@kde.org>
+ * Copyright 2017-2018  Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "kmymoneycalculator.h"
 
@@ -46,8 +41,16 @@ class KMyMoneyCalculatorPrivate
   Q_DISABLE_COPY(KMyMoneyCalculatorPrivate)
 
 public:
-  KMyMoneyCalculatorPrivate()
+  KMyMoneyCalculatorPrivate() :
+    op0(0.0),
+    op1(0.0),
+    op(0),
+    stackedOp(0),
+    display(nullptr),
+    m_clearOperandOnDigit(false)
   {
+    for (auto& button : buttons)
+      button = nullptr;
   }
 
   /**
@@ -197,8 +200,8 @@ KMyMoneyCalculator::KMyMoneyCalculator(QWidget* parent) :
 
   d->buttons[KMyMoneyCalculatorPrivate::EQUAL]->setFocus();
 
-  d->op1 = 0.0;
-  d->stackedOp = d->op = d->op0 = 0;
+  d->op1 = d->op0 = 0.0;
+  d->stackedOp = d->op = 0;
   d->operand.clear();
   changeDisplay("0");
 
